# Creating a Culture of Innovation
We aspire to create a culture where people work joyfully, communicate openly
about things that matter, and provide great services globally. We would like our
team and communities (both government and private sector) to reflect on
diversity of all kinds, not just the classes protected in law. Diversity fosters
innovation. Diverse teams are creative teams. We need a diversity of perspective
to create solutions for the challenges we face.

This is our code of conduct (adapted from [18F's Code of Conduct](https://github.com/18F/code-of-conduct)).
We follow all Equal Employment Opportunity laws and we expect everyone we work
with to adhere to the [GSA Anti-harrasment Policy](http://www.gsa.gov/portal/directive/d0/content/512516),
even if they do not work for the Centers for Disease Control and Prevention or
GSA. We expect every user to follow this code of conduct and the laws and
policies mentioned above.

## Be Empowering
Consider what you can do to encourage and support others. Make room for quieter
voices to contribute. Offer support and enthusiasm for great ideas. Leverage the
low cost of experimentation to support your colleagues' ideas, and take care to
acknowledge the original source. Look for ways to contribute and collaborate,
even in situations where you normally wouldn't. Share your knowledge and skills.
Prioritize access for and input from those who are traditionally excluded from
the civic process.

## Rules of Behavior
 * I understand that I must complete security awareness and records management
   training annually in order to comply with the latest security and records
   management policies.
 * I understand that I must also follow the [Rules of Behavior for use of HHS Information Resources](http://www.hhs.gov/ocio/policy/hhs-rob.html)
 * I understand that I must not use, share, or store any kind of sensitive data
   (health status, provision or payment of healthcare, PII, etc.) under ANY
   circumstance.
 * I will not knowingly conceal, falsify, or remove information.
 * I understand that I can only use non-sensitive and/or publicly available
   data.
 * I understand that all passwords I create to set up accounts need to comply
   with CDC's password policy.
 * I understand that the stewards reserves the right to moderate all data at any
   time.

## Boundaries
Create boundaries to your own behavior and consider how you can create a safe
space that helps prevent unacceptable behavior by others. We can't list all
instances of unacceptable behavior, but we can provide examples to help guide
our community in thinking through how to respond when we experience these types
of behavior, whether directed at ourselves or others.

If you are unsure if something is appropriate behavior, it probably is not. Each
person we interact with can define where the line is for them. Impact matters
more than intent. Ensuring that your behavior does not have a negative impact is
your responsibility. Problems usually arise when we assume that our way of
thinking or behavior is the norm for everyone.

### Here are some examples of unacceptable behavior
 * Negative or offensive remarks based on the protected classes as listed in the
   GSA Anti-harrasment Policy of race, religion, color, sex, national origin,
   age, disability, genetric information, sexual orientation, gender identity,
   parental status, maritual status, and political affiliation as well as gender
   expression, mental illness, socioeconomic status or backgrounds,
   neuro(a)typicality, physical appearance, body size, or clothing. Consider
   that calling attention to differences can feel alienating.
 * Sustained disruption of meetings, talks, or discussions, including chatrooms.
 * Patronizing language or behavior.
 * Aggresive behavior, such as unconstructive criticism, providing correction
   that do not improve the conversation (sometimes referred to as "well
   actually's"), repeatedly interrupting or talking over someone else, feigning
   surprise at someone's lack of knowledge or awareness about a topic, or subtle
   prejudice.
 * Referring to people in a way that misidentifies their gender and/or rejects
   the validity of their gender identity; for instance by using incorrect
   pronouns or forms of address (misgendering).
 * Retaliating against anyone who files a formal complaint that someone has
   violated these codes or laws.

## Background
CDC Scientific Clearance is the process of obtaining approvals by appropriate
CDC officials before a CDC information product is released to the public or
CDC's external public health partners. Information products that require formal
clearance include print, electronic, or oral materials, that CDC employees
author or co-author, whether published by CDC or outside CDC. CDC contractors
developing content on behalf of CDC for the public or CDC's external public
health partners are also required to put their content through the formal
clearance process. The collaborative functions related to the projects include
blogs, wikis, forums, bug tracking sites, source control and
others deemed as necessary.

For those individuals within the CDC, adherence to the following policies are
required:
* CDC ["Clearance of Information Products Disseminated Outside CDC for Public Use"](http://www.cdc.gov/maso/Policy/PublicUse.pdf)
* HHS ["Ensuring the Quality of Information Disseminated by HHS agencies"](http://aspe.hhs.gov/infoquality)

All collaborative materials will be controlled by the rules contained within
this document. This will allow for the real-time collaboration opportunities
among CDC employees, CDC contractors and CDC public health partners.

## Credit
This code of conduct was mainly adapted from [18F's Code of Conduct](https://github.com/18F/code-of-conduct)
and the [CDC's Informatics Innovation Unit R&D Lab's code of conduct.](https://www.philab.cdc.gov/index.php/code-of-conduct/)

## Relevant Legal Considerations
* [Laws enforced by the Equal Employment Opportunity Commission](http://www.eeoc.gov/laws/statutes/index.cfm)
* [Types of discrimination prohibited by law](http://www.eeoc.gov/laws/types)
* [New and proposed regulations](http://www.eeoc.gov/laws/regulations/index.cfm)
